@@ -2,9 +2,4 @@
 hence make it possible to run all unittests from the top level direcotry with
 
         python -m unittest [discover]
-
-and
-
-        python setup.py test
-
 """
