@@ -49,21 +49,21 @@ class TestSearchQueryPreparation(unittest.TestCase):
         self.assertEqual(expected, prepared["foo"])
 
 
-class TestAddEmail(unittest.TestCase):
+class TestFindEmailAddress(unittest.TestCase):
 
-    def test_find_email_addresses_empty_text_finds_none(self):
+    def test_empty_text_finds_none(self):
         text = ""
         addrs = find_email_addresses(text, ["from"])
         self.assertEqual([], addrs)
 
-    def test_find_email_addresses_single_header_finds_one_address(self):
+    def test_single_header_finds_one_address(self):
         text = """From: John Doe <jdoe@machine.example>"""
         addrs = find_email_addresses(text, ["from"])
         expected = [Address(display_name="John Doe",
                             username="jdoe", domain="machine.example")]
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_single_header_finds_multiple_addresses(self):
+    def test_single_header_finds_multiple_addresses(self):
         text = """From: John Doe <jdoe@machine.example>, \
                 Mary Smith <mary@example.net>"""
         addrs = find_email_addresses(text, ["from"])
@@ -78,14 +78,14 @@ class TestAddEmail(unittest.TestCase):
                 domain="example.net")]
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_non_address_header_finds_none(self):
+    def test_non_address_header_finds_none(self):
         text = "From: John Doe <jdoe@machine.example>, " \
             "Mary Smith <mary@example.net>\nOther: test"
         addrs = find_email_addresses(text, ["other"])
         expected = []
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_multiple_headers_finds_some(self):
+    def test_multiple_headers_finds_some(self):
         text = "From: John Doe <jdoe@machine.example>, " \
             "Mary Smith <mary@example.net>\nOther: test"
         addrs = find_email_addresses(text, ["other", "from"])
@@ -100,7 +100,7 @@ class TestAddEmail(unittest.TestCase):
                 domain="example.net")]
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_multiple_headers_finds_all(self):
+    def test_multiple_headers_finds_all(self):
         text = "From: John Doe <jdoe@machine.example>, " \
             "Mary Smith <mary@example.net>\n" \
             "To: Michael Jones <mjones@machine.example>"
@@ -120,7 +120,7 @@ class TestAddEmail(unittest.TestCase):
                 domain="example.net")]
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_finds_all_emails(self):
+    def test_finds_all_emails(self):
         text = "From: John Doe <jdoe@machine.example>, " \
             "Mary Smith <mary@example.net>\n" \
             "To: Michael Jones <mjones@machine.example>"
@@ -140,7 +140,7 @@ class TestAddEmail(unittest.TestCase):
                 domain="machine.example")]
         self.assertEqual(expected, addrs)
 
-    def test_find_email_addresses_finds_all_emails_with_other_headers_too(
+    def test_finds_all_emails_with_other_headers_too(
             self):
         text = "From: John Doe <jdoe@machine.example>, " \
             "Mary Smith <mary@example.net>\n" \
